# Copyright (c) 2012-1015 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

# vim: set sw=4 ts=4 et nu:

%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}

Name:           puddletag
Version:        1.0.5
Release:        1.1
Summary:        Audio Tag Editor
Source:         http://prdownloads.sourceforge.net/puddletag/puddletag-%{version}.tar.gz
Source99:       puddletag-rpmlintrc
URL:            http://puddletag.sourceforge.net
Group:          Productivity/Multimedia/Sound/Editors and Convertors
License:        GPL-2.0+
BuildRoot:      %{_tmppath}/build-%{name}-%{version}
BuildRequires:  python-devel
BuildRequires:  update-desktop-files
BuildRequires:  python-qt4 >= 4.5
BuildRequires:  python-mutagen >= 1.14
BuildRequires:  python-musicbrainz2
BuildRequires:  python-pyparsing > 1.4
BuildRequires:  python-configobj
BuildRequires:  python-imaging
Requires:       python-qt4 >= 4.5
Requires:       python-mutagen >= 1.14
Requires:       python-musicbrainz2
Requires:       python-pyparsing > 1.4
Requires:       python-configobj
Requires:       python-imaging
%py_requires
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description
puddletag is a tag editor for Linux loosely based on mp3tag. It uses a table
layout so that all the tags you want to edit by hand are visible and easily
editable. puddletag excels at automating repetitive tasks like extracting tag
information from filenames, tagging files from a text file or the clipboard,
renaming or moving files and folders based on tags by using patterns, and
manipulating tags using actions and regular expressions. Supported formats
include id3v1, id3v2 (.mp3), AAC (.m4a), VorbisComments (.ogg, .flac), and
APEv2 (.ape). Much of mp3tag's functionality has been replicated with added
enhancements and tweaks.

%prep
%setup -q
%__chmod 0644 HACKING NEWS README THANKS TODO copyright

# remove bogus shebangs
find puddlestuff/ -type f -exec %__perl -i -ne 'print unless $.==1 and /^#!/' {} \;

%build
%__python ./setup.py build

%install
%__python ./setup.py install \
    --prefix="%{_prefix}" \
    --root="%{buildroot}" \
    --record-rpm=files.lst

# remove directories that are owned by others
%__perl -i -ne 'print unless m,^(%dir\s+)?%{_datadir}/(applications|pixmaps)/*$,' files.lst

# remove man page, as it is compressed by rpmbuild
%__perl -i -ne 'print unless m,^%{_mandir},' files.lst

%suse_update_desktop_file -r "%{name}" Multimedia AudioVideoEditing

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files -f files.lst
%defattr(-,root,root)
%doc HACKING NEWS README THANKS TODO copyright
%doc %{_mandir}/man1/puddletag.1*

%changelog
* Mon Feb 23 2015 malcolmlewis@opensuse.org
- Update to version 1.0.5:
  * Fixed a bug in actions where floating point values weren't
    getting handled correctly. Could cause puddletag to lock up.
- Changes from 1.0.4:
  * Fixed regular expression parsing.
  * Fixed discogs API no longer working. Fixed it so that searches
    can be done using Discogs release id only.
  * Fixed comparison of boolean values in format strings.
  * Fixed scripting function escaping wasn't working.
  * Changed all config options are stored as JSON. Should fix
    issues with not being able to store certain values.
  * Added $to_num scripting function. Converts text to numbers for
    easy comparison.
  * Added AIFF support.
  * Added configuration is stored using XDG dirs. Settings are in
    ~/.config/puddletag and ~/.local/share/puddletag.
- Changes from 1.0.3:
  * Fixed placeholder causing puddletag to not start up for
    Qt < 4.7.
  * Fixed new version of configobj library not saving unicode
    objects.
  * Fixed __num_images count for mp3 and ogg.
* Thu Jan 23 2014 pascal.bleser@opensuse.org
- update to 1.0.2:
  * fixed: escaped chars in functions weren't being escaped correctly
  * added: Opus support
  * added: artwork windows list JPG + PNG's at the same time
* Sat Oct 13 2012 pascal.bleser@opensuse.org
- update to 1.0.1
* Tue Jun  7 2011 pascal.bleser@opensuse.org
- update to 0.10.6:
  * fix for freezes if Update empty fields and 'Retrieve exact matches.'
    checked in Tag Sources dialog
- changes from 0.10.4:
  * add French translation
  * add man page
  * new logo
  * added data files to source tarball
  * added documentation to source tarball.
  * New Features:
    + much improved masstagging
    + save artwork to file Function
    + Filter that behaves like Mp3tag's
    + in Discogs tag source: added the ability to retrieve track artists for
    various Artist albums
    + tag to filename and Tag->Dir functions handle patterns like '../%%artist%%'
    and './%%artist%%/%%album%%' correctly
    + options for setting the pattern used in saving covers to file dialogs
  * Fixes:
    + multiple value handling for ID3v2.3
    + when editing actions, if a field not in the current list of fields was
    used, then the list of saved fields would contain only that field
    + undoing renaming of dirs
    + patterns that use scripting functions like $validate(arg1,,arg3) will
    work correctly in that the second argument will evaluate to an empty string
    instead of being discarded
    + issue 132: images weren't being added to list of fields to undo
    + for Discogs Tag Source: Images were being retrieved even if disabled when
    using textual searches
    + changing file in Extended Tags changes the selection in File-View,
    thereby ensuring changes are written to the correct file
  * Changes:
    + unicode support for Replace with Regular Expression function
    + renaming dirs hooks into Tag->Dir function now
    + the lyrics_us field is now unsyncedlyrics
    + functions dialog restores last used function upon first load
    + a couple related to the QuodLibet library handling
    + proper error messages differentiating whether the error occurred while
    writing to files or renaming dirs, files
    + the semi-colon character(';') has been removed from the list of invalid
    filename chars
* Mon Apr  4 2011 pascal.bleser@opensuse.org
- update to 0.10.3:
  * fixes:
    + deleting tags containing mapped fields
    + functions operating on multiple values like Merge Field were broken
    + peformersortorder is spelt correctly as performersortorder for ID3 tags
    + renaming directories when intermediate directories are to be created
- changes from 0.10.1:
  * new features:
    + loading subfolders can be turned on/off using the Filesystem Window
    + USLT Frame support for ID3
    + a bunch of new fields
    + stored Tags window shows the values of all tags found in file
    + experimental ID3 support. Don't use unless you really need to
  * fixes:
    + retrieving PUIDS using the MusicBrainz tag source
    + adding album art from Tag Source was defective
    + the Tag Panel not updating with 'previewed' values
    + properties window not showing
  * changes:
    + values in the Stored Tags window aren't emboldened anymore due to
    performance reasons
* Thu Mar 10 2011 pascal.bleser@opensuse.org
- update to 0.10.0:
  * new cover art support for all formats (except ASF)
  * loading master releases in the Discogs.com tag source
  * for ID3 tags, UFID frames are only loaded if data can be decoded to UTF-8
  * MusicBrainz artist search retrieves 100 albums by default
  * initial reading of a directory can be canceled now
  * uncaught errors for Tag Sources shouldn't leave the Tag Sources window
    disabled anymore
  * Discogs artist/albums are parsed correctly instead of looking weird
  * Amazon keyword search wasn't working at all
  * having periods in the Tag->Dir function were causing problems
* Mon Dec 27 2010 pascal.bleser@opensuse.org
- update to 0.9.11:
  * the "Tag -> Dir" feature can move directories
  * incorrectly encoded files are corrected
  * selected files can be moved up or down in file-view
  * the MusicBrainz tag source now retrieves more fields
  * the Discogs.com tag source was added, including artwork
  * the "Select All in Dir" function supports "Select All" in the previous or
    next directory
  * tentative support was added for Mp3tag's tag sources
  * language translations were added
  * the "~" notation can now be used to exclude fields in function calls
  * separate options were added to remove ID3v1 and ID3v2 tags
  * matches optionally can be automatically retrieved using Tag Sources
  * shortcuts were assigned to Actions
  * the default file sort order is now remembered
* Sun Dec 19 2010 pascal.bleser@opensuse.org
- initial package (0.9.10)
